@@ -9,17 +9,17 @@ Rsomoclu.train <-
            radiusCooling, scale0, scaleN,
            scaleCooling,
            kernelType=0, mapType="planar", gridType="rectangular", 
-           compactSupport=FALSE, codebook=NULL) {
+           compactSupport=FALSE, neighborhood="gaussian", codebook=NULL) {
     if (is.null(codebook)) {
-      codebook <- numeric(nSomX*nSomY*dim(input_data)[2])
-      codebook[1] <- 1000
-      codebook[1] <- 2000
+      codebook <- matrix(data = 0, nrow = nSomX * nSomY, ncol = dim(input_data)[2])
+      codebook[1, 1] <- 1000
+      codebook[2, 1] <- 2000
     }
     res <- .Call("Rtrain", input_data, nEpoch,
                  nSomX, nSomY, radius0, radiusN,
                  radiusCooling, scale0, scaleN,
                  scaleCooling, kernelType, mapType,
-                 gridType, compactSupport,
+                 gridType, compactSupport, neighborhood,
                  codebook)
     res
 }
