@@ -1,6 +1,6 @@
 library('Rsomoclu')
 data_file <- system.file("data", "rgbs.txt.gz", package = 'Rsomoclu')
-input_data <- read.table(data_file) 
+input_data <- read.table(data_file)
 input_data <- data.matrix(input_data)
 nSomX <- 50
 nSomY <- 50
@@ -16,11 +16,13 @@ mapType <- "planar"
 gridType <- "rectangular"
 compactSupport <- FALSE
 codebook <- NULL
+neighborhood <- "gaussian"
 res <- Rsomoclu.train(input_data, nEpoch, nSomX, nSomY,
                       radius0, radiusN,
                       radiusCooling, scale0, scaleN,
                       scaleCooling,
-                      kernelType, mapType, gridType, compactSupport)
+                      kernelType, mapType, gridType, 
+                      compactSupport, neighborhood, codebook)
 res$codebook
 res$globalBmus
 res$uMatrix
